Support
======= 

If you have any question or problem, please check this documentation first.

Otherwise we will be happy to provide you any support.

Bugs & Issues
-------------

If you find a bug or an issue, you can visit our 
`issue tracker <https://github.com/C2SM-RCM/emiproc/issues>`_ .


.. _contact:

Contact
-------

`emiproc official repository <https://github.com/C2SM-RCM/emiproc>`_
is managed by 
the
`Group Atmospheric Modelling and Remote Sensing <https://www.empa.ch/web/s503/team-modelling>`_
which is a group from the 
`Laboratory for Air Pollution / Environmental Technology from Empa <https://www.empa.ch/web/empa/air-pollution-/-environmental-technology>`_


The prefered way of contacting us is through the github page.


History 
-------

Emiproc was originally published for the OEM of ICON in [Jähn_et_al_2020]_.
In 2022 it was refactored with a more modular and object-oriented design,
in order to account for more inventories and models.

License
-------

Since 2024, emiproc is licensed by Empa under The 3-Clause BSD License. 